@@ -15,6 +15,7 @@ from mypy.plugin import (
     AnalyzeTypeContext,
     ClassDefContext,
     DynamicClassDefContext,
+    FunctionContext,
     Plugin,
     SemanticAnalyzerPluginInterface,
 )
@@ -39,6 +40,13 @@ def lazy_type_analyze_callback(ctx: AnalyzeTypeContext) -> Type:
     return type_
 
 
+def strawberry_field_hook(ctx: FunctionContext) -> Type:
+    # TODO: check when used as decorator, check type of the caller
+    # TODO: check type of resolver if any
+
+    return AnyType(TypeOfAny.special_form)
+
+
 def private_type_analyze_callback(ctx: AnalyzeTypeContext) -> Type:
     type_name = ctx.type.args[0]
     type_ = ctx.api.analyze_type(type_name)
@@ -178,6 +186,14 @@ class StrawberryPlugin(Plugin):
 
         return None
 
+    def get_function_hook(
+        self, fullname: str
+    ) -> Optional[Callable[[FunctionContext], Type]]:
+        if fullname == "strawberry.field.field":
+            return strawberry_field_hook
+
+        return None
+
     def get_type_analyze_hook(self, fullname: str):
         if fullname == "strawberry.lazy_type.LazyType":
             return lazy_type_analyze_callback
